@@ -9,7 +9,7 @@ use TAP::Parser::Iterator::Process ();
 @ISA = qw(TAP::Parser::SourceHandler);
 TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 
-our $VERSION = '3.32';
+our $VERSION = '3.33';
 
 =head1 Name
 
@@ -309,7 +309,7 @@ sub make_iterator {
       --no-psqlrc
       --no-align
       --quiet
-      --pset pager=
+      --pset pager=off
       --pset tuples_only=true
       --set ON_ERROR_STOP=1
     );
